[−][src]Enum unicode_types::ethiopic_extended::EthiopicExtended
An enum to represent all characters in the EthiopicExtended block.
Variants
EthiopicSyllableLoa\u{2d80}: 'ⶀ'
EthiopicSyllableMoa\u{2d81}: 'ⶁ'
EthiopicSyllableRoa\u{2d82}: 'ⶂ'
EthiopicSyllableSoa\u{2d83}: 'ⶃ'
EthiopicSyllableShoa\u{2d84}: 'ⶄ'
EthiopicSyllableBoa\u{2d85}: 'ⶅ'
EthiopicSyllableToa\u{2d86}: 'ⶆ'
EthiopicSyllableCoa\u{2d87}: 'ⶇ'
EthiopicSyllableNoa\u{2d88}: 'ⶈ'
EthiopicSyllableNyoa\u{2d89}: 'ⶉ'
EthiopicSyllableGlottalOa\u{2d8a}: 'ⶊ'
EthiopicSyllableZoa\u{2d8b}: 'ⶋ'
EthiopicSyllableDoa\u{2d8c}: 'ⶌ'
EthiopicSyllableDdoa\u{2d8d}: 'ⶍ'
EthiopicSyllableJoa\u{2d8e}: 'ⶎ'
EthiopicSyllableThoa\u{2d8f}: 'ⶏ'
EthiopicSyllableChoa\u{2d90}: 'ⶐ'
EthiopicSyllablePhoa\u{2d91}: 'ⶑ'
EthiopicSyllablePoa\u{2d92}: 'ⶒ'
EthiopicSyllableGgwa\u{2d93}: 'ⶓ'
EthiopicSyllableGgwi\u{2d94}: 'ⶔ'
EthiopicSyllableGgwee\u{2d95}: 'ⶕ'
EthiopicSyllableGgwe\u{2d96}: 'ⶖ'
EthiopicSyllableSsa\u{2da0}: 'ⶠ'
EthiopicSyllableSsu\u{2da1}: 'ⶡ'
EthiopicSyllableSsi\u{2da2}: 'ⶢ'
EthiopicSyllableSsaa\u{2da3}: 'ⶣ'
EthiopicSyllableSsee\u{2da4}: 'ⶤ'
EthiopicSyllableSse\u{2da5}: 'ⶥ'
EthiopicSyllableSso\u{2da6}: 'ⶦ'
EthiopicSyllableCca\u{2da8}: 'ⶨ'
EthiopicSyllableCcu\u{2da9}: 'ⶩ'
EthiopicSyllableCci\u{2daa}: 'ⶪ'
EthiopicSyllableCcaa\u{2dab}: 'ⶫ'
EthiopicSyllableCcee\u{2dac}: 'ⶬ'
EthiopicSyllableCce\u{2dad}: 'ⶭ'
EthiopicSyllableCco\u{2dae}: 'ⶮ'
EthiopicSyllableZza\u{2db0}: 'ⶰ'
EthiopicSyllableZzu\u{2db1}: 'ⶱ'
EthiopicSyllableZzi\u{2db2}: 'ⶲ'
EthiopicSyllableZzaa\u{2db3}: 'ⶳ'
EthiopicSyllableZzee\u{2db4}: 'ⶴ'
EthiopicSyllableZze\u{2db5}: 'ⶵ'
EthiopicSyllableZzo\u{2db6}: 'ⶶ'
EthiopicSyllableCcha\u{2db8}: 'ⶸ'
EthiopicSyllableCchu\u{2db9}: 'ⶹ'
EthiopicSyllableCchi\u{2dba}: 'ⶺ'
EthiopicSyllableCchaa\u{2dbb}: 'ⶻ'
EthiopicSyllableCchee\u{2dbc}: 'ⶼ'
EthiopicSyllableCche\u{2dbd}: 'ⶽ'
EthiopicSyllableCcho\u{2dbe}: 'ⶾ'
EthiopicSyllableQya\u{2dc0}: 'ⷀ'
EthiopicSyllableQyu\u{2dc1}: 'ⷁ'
EthiopicSyllableQyi\u{2dc2}: 'ⷂ'
EthiopicSyllableQyaa\u{2dc3}: 'ⷃ'
EthiopicSyllableQyee\u{2dc4}: 'ⷄ'
EthiopicSyllableQye\u{2dc5}: 'ⷅ'
EthiopicSyllableQyo\u{2dc6}: 'ⷆ'
EthiopicSyllableKya\u{2dc8}: 'ⷈ'
EthiopicSyllableKyu\u{2dc9}: 'ⷉ'
EthiopicSyllableKyi\u{2dca}: 'ⷊ'
EthiopicSyllableKyaa\u{2dcb}: 'ⷋ'
EthiopicSyllableKyee\u{2dcc}: 'ⷌ'
EthiopicSyllableKye\u{2dcd}: 'ⷍ'
EthiopicSyllableKyo\u{2dce}: 'ⷎ'
EthiopicSyllableXya\u{2dd0}: 'ⷐ'
EthiopicSyllableXyu\u{2dd1}: 'ⷑ'
EthiopicSyllableXyi\u{2dd2}: 'ⷒ'
EthiopicSyllableXyaa\u{2dd3}: 'ⷓ'
EthiopicSyllableXyee\u{2dd4}: 'ⷔ'
EthiopicSyllableXye\u{2dd5}: 'ⷕ'
EthiopicSyllableXyo\u{2dd6}: 'ⷖ'
EthiopicSyllableGya\u{2dd8}: 'ⷘ'
EthiopicSyllableGyu\u{2dd9}: 'ⷙ'
EthiopicSyllableGyi\u{2dda}: 'ⷚ'
EthiopicSyllableGyaa\u{2ddb}: 'ⷛ'
EthiopicSyllableGyee\u{2ddc}: 'ⷜ'
EthiopicSyllableGye\u{2ddd}: 'ⷝ'
EthiopicSyllableGyo\u{2dde}: 'ⷞ'
Methods
impl EthiopicExtended[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case